<?php
/*
Plugin Name: Blog Topics Widget
Plugin URI: 
Description: Adds a sidebar widget to display Blog's Topic and/or Recent Posts
Author: Deanna Schneider
Copyright:

    Copyright 2008 CETS

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111_1307  USA

*/

// This gets called at the plugins_loaded action
function widget_cets_blog_topics_init() {

	// check for sidebar existance
	if ( !function_exists('register_sidebar_widget') || !function_exists('register_widget_control') )
		return;

	// Check for the required blog topic class
	if ( !class_exists('cets_blog_topics') )
		return;
	
	$widget_title = "Blog Topics";
	$widget_description = "Show the blog's current topic, optional linked list of related blogs, optional linked list of related recent posts. Blogs and posts are ordered by most recent activity";

	// This saves options and prints the widget's config form.
	function widget_cets_blog_topics_control() {
		global $blog_id;
		$thistopic =  cets_get_blog_topic_name($blog_id);
		
		
		$options = get_option('widget_cets_blog_topics');
		
		// this section sets defaults
		if ( !is_array($options) )
			$options = array('blogs_title'=>'Related Blogs',
			 'topic_title' => 'Topic',
			 'limit'=>'5',
			 'include_topic' => TRUE,
			 'include_related' => TRUE,
			 'include_related_posts' => FALSE,
			 'post_title'=> 'Related Posts',
			 'postrows' => '5');
			 
		// let's try to manually set this option	 
		update_option('widget_cets_blog_topics', $options);	 
		
		
			 
		// here we set the options to whatever was posted		
		if ( $_POST['cets_bt_submit'] ) {
			$options['topic_title'] = strip_tags(stripslashes($_POST['cets_bt_topic_title']));
			$options['blogs_title'] = strip_tags(stripslashes($_POST['cets_bt_blogs_title']));
			$options['maxrows'] = strip_tags(stripslashes($_POST['cets_bt_maxrows']));
			$options['postrows'] = strip_tags(stripslashes($_POST['cets_bt_postrows']));
			$options['include_topic'] = $_POST['cets_bt_include_topic'];
			$options['include_related'] = $_POST['cets_bt_include_related'];
			$options['include_related_posts'] = $_POST['cets_bt_include_related_posts'];
			$options['posts_title'] = strip_tags(stripslashes($_POST['cets_bt_posts_title']));
			$options['postrows'] = strip_tags(stripslashes($_POST['cets_bt_postrows']));
			
		}
		
		// Update the options
		update_option('widget_cets_blog_topics', $options);
		
		// Figure out the default state for the checkboxes
		$include_related_topic = ( $options['include_topic'] == TRUE ) ? ' checked="checked"' : '';
		$include_related_checked = ( $options['include_related'] == TRUE ) ? ' checked="checked"' : '';
		$include_related_posts_checked = ( $options['include_related_posts'] == TRUE ) ? ' checked="checked"' : '';

	?>
			
                
                
				<strong>Blog topic: <?php echo($thistopic); ?></strong>
                <p style="line_height: 100%">
                <label for="cets_bt_include_topic"  style="line_height:25px;display:block;"><?php _e('Include Topic:', 'widgets'); ?> <input type="checkbox" id="cets_bt_include_topic" name="cets_bt_include_topic" <?php echo($include_related_topic) ?> value="TRUE" /></label><br/>
                <label for="cets_bt_title" style="line_height:25px;display:block;"><?php _e('Topic Title:', 'widgets'); ?> <input type="text" id="cets_bt_topic_title" name="cets_bt_topic_title" value="<?php echo wp_specialchars($options['topic_title'], true); ?>" /></label><br/>
                
                </p>
                
                <hr />
                <strong>Sitewide Related Blogs</strong>
                <p style="line_height: 100%;">
                <label for="cets_bt_include_related"  style="line_height:25px;display:block;"><?php _e('Include Related Blogs:', 'widgets'); ?> <input type="checkbox" id="cets_bt_include_related" name="cets_bt_include_related" <?php echo($include_related_checked) ?> value="TRUE" /></label><br/>
				<label for="cets_bt_title" style="line_height:25px;display:block;"><?php _e('Title:', 'widgets'); ?> <input type="text" id="cets_bt_blogs_title" name="cets_bt_blogs_title" value="<?php echo wp_specialchars($options['blogs_title'], true); ?>" /></label><br/>
               
                <label for="cets_bt_maxrows" style="line_height:25px;display:block;"><?php _e('Number of related blogs to include:', 'widgets'); ?> <input type="text" id="cets_bt_maxrows" name="cets_bt_maxrows" style="width: 2em;" value="<?php echo wp_specialchars($options['maxrows'], true); ?>" /></label>
                </p>
                <hr />
                <strong>Sitewide Related Posts</strong>
                 <p style="line_height: 100%;">
                 <label for="cets_bt_include_related_posts"  style="line_height:25px;display:block;"><?php _e('Include related Posts:', 'widgets'); ?> <input type="checkbox" id="cets_bt_include_related_posts" name="cets_bt_include_related_posts" <?php echo($include_related_posts_checked) ?> value="TRUE" /></label><br/>
                <label for="cets_bt_p_title" style="line_height:25px;display:block;"><?php _e('Title:', 'widgets'); ?> <input type="text" id="cets_bt_posts_title" name="cets_bt_posts_title" value="<?php echo wp_specialchars($options['posts_title'], true); ?>" /></label><br/>
                 <label for="cets_bt_postrows" style="line_height:25px;display:block;"><?php _e('Number of related posts to include:', 'widgets'); ?> <input type="text" id="cets_bt_postrows" name="cets_bt_postrows" style="width: 2em;" value="<?php echo wp_specialchars($options['postrows'], true); ?>" /></label>
                
                </p>
				
				<input type="hidden" name="cets_bt_submit" id="cets_bt_submit" value="TRUE" />
				
	<?php
	}

	// This prints the widget
	function widget_cets_blog_topics($args) {
		extract($args);
		global $blog_id;
		$this_id = $blog_id;
		//$widget_title = 'Topic';
		$maxrows_default = 0; // this is no limit
		$postrows_default = 10; // we'll default to 10 otherwise the query gets too huge
		$options = get_option('widget_cets_blog_topics');
		$title = !isset($options['title']) == 0 ? $widget_title : $options['title'];
		
		// check to see if they added a number for the maxrows to include
		if (strlen($options['maxrows']) == 0) {
			// if no number, set it to the default 
			$options['maxrows'] = $maxrows_default;
		}
		
		// if they entered something that's not a number, set it to 5
		if (!$options['maxrows'] == (int) $options['maxrows']) {
			$maxrows = 5;
		}
		else {
			// otherwise, let them choose how many
			$maxrows = $options['maxrows'];
		}
		
		// check to see if they added a number for the postrows to include
		if (strlen($options['postrows']) == 0) {
			// if no number, set it to the default 
			$options['postrows'] = $postrows_default;
		}
		
		// if they entered something that's not a number, set it to 5
		if (!$options['postrows'] == (int) $options['postrows']) {
			$postrows = 5;
		}
		else {
			// otherwise, let them choose how many
			$postrows = $options['postrows'];
		}
		
		
		// get the topic id from the blogid
		$topic_id = cets_get_topic_id_from_blog_id($this_id);
		// get the name of the topic
		$topic = cets_get_blog_topic_name($this_id);
		
		// this is the first widget - the blog topic
		if ($options['include_topic'] == TRUE){
			echo $before_widget . $before_title . $options['topic_title']  . $after_title;
			//echo $topic;
			echo ("<a href='" .get_settings('siteurl'). "/cets_blog_topics_list.php?idtopic=$topic_id'>" . $topic . "</a>");
			echo $after_widget;
		}
		
		// this is the second widget - the sitewide related blogs
		if ($options['include_related'] == TRUE) {
			echo $before_widget . $before_title . $options['blogs_title']  . $after_title;
			cets_get_blogs_from_topic_id_html($topic_id, $maxrows, $this_id);
			echo $after_widget;
		
		}
		
		// this is the third widget - the sitewide recent posts
		if ($options['include_related_posts'] == TRUE) {
			echo $before_widget . $before_title . $options['posts_title']  . $after_title;
			
			cets_get_recent_posts_from_topic_id_html($topic_id, $postrows, $this_id);
			echo $after_widget;
		
		}
		
		

	}


	// Tell Dynamic Sidebar about our new widget and its control
	$widget_ops = array('classname' => 'widget_cets_blog_topics', 'description' => __( "$widget_description") );
	$control_ops = array('width' => 280);
	wp_register_sidebar_widget('widget_cets_blog_topics', $widget_title, 'widget_cets_blog_topics', $widget_ops);
	wp_register_widget_control('widget_cets_blog_topics', $widget_title, 'widget_cets_blog_topics_control', $control_ops );
	//register_sidebar_widget(array('Blog Topic', 'widgets'), 'widget_cets_blog_topics');
	//register_widget_control(array('Blog Topic', 'widgets'), 'widget_cets_blog_topics_control');

}

// Delay plugin execution to ensure Dynamic Sidebar has a chance to load first
add_action('plugins_loaded', 'widget_cets_blog_topics_init');

?>
