<?php
/******************************************************************************************************************
 
Plugin Name: cets_blogtopics

Plugin URI:

Description: WordPressMU plugin for classifying blogs into topics. 

Version: 0.2

Author: Deanna Schneider (http://deannaschneider.wordpress.com)

Thanks goes out to Ezequiel Conte (http://code.google.com/p/cetsopensource/) for getting me started.

Copyright:

    Copyright 2008 CETS

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

            
*******************************************************************************************************************/

class cets_blog_topics 
{
    var $table_topics;
	
	function cets_blog_topics() 
	{	
		global $table_prefix,$wpdb;

		$this->table_topics  = $wpdb->blogs . "_cets_topics";
		$this->table_relationships = $wpdb->blogs . "_cets_topics_relationships";

	}
	
    function setup() 
    {
	    global $wpdb;
	    
	    //check if table was already created
	    if($wpdb->get_var("show tables like '$this->table_topics'") != $this->table_topics) {
			// if not create the topic table
	    	$table_topics_query = "CREATE TABLE $this->table_topics (
						      id int(11) unsigned NOT NULL auto_increment,
						      topic_name VARCHAR(55) NOT NULL default '',
							  active int(1) unsigned NOT NULL default 1,
						      UNIQUE KEY id (id)
						      )";	  
 			
 			$results = $wpdb->query($table_topics_query);
			
			//create the relationships table
			$table_relationships_query = "CREATE TABLE $this->table_relationships (
						  blog_id int(11) unsigned NOT NULL,
						  topic_id int(11) unsigned NOT NULL, 
						  UNIQUE KEY id (blog_id, topic_id)
						  )";
			$results = $wpdb->query($table_relationships_query);			  
		
 			
			//insert topics into database
		    $topics = array('Uncategorized');
		    
		    
		    foreach ( $topics as $topic ) {
		    	$insert = "INSERT INTO $this->table_topics (topic_name) VALUES ('$topic');";  
		    	$results = $wpdb->query( $insert );	
		    }
		    
		    
		    //add blog_topic to every blog
			$blog_list = $wpdb->get_results( "SELECT blog_id FROM $wpdb->blogs;");
			 
			foreach ( $blog_list as $blog ) {
				$this->set_blog_topic($blog->blog_id,'1');
			}
		    
	    }
		
		// Add a site option so that we'll know set up ran
		add_site_option( 'cets_blogtopics_setup', 1 );
	    		
    }
	
	

    function get_blogs_from_topic_id($topic_id, $max_rows = 0, $blog_id = 0) // max_rows limits the query, $blog_id drops out the blog on which the widget is
    {
    	global $wpdb, $wpmuBaseTablePrefix;
    	
		// validate inputs
		if (!$topic_id = (int) $topic_id) $topic_id = 1;
		if (!$max_rows = (int) $max_rows) $max_rows = 0;
		if (!$blog_id =  (int) $blog_id) $blog_id = 0;
		
		$statement = "SELECT distinct b.blog_id FROM $wpdb->blogs b INNER JOIN $this->table_relationships r ON b.blog_id = r.blog_id  INNER JOIN $this->table_topics c ON r.topic_id = c.id AND c.active = 1 WHERE r.topic_id = $topic_id and b.archived = '0' and b.spam = '0' and b.deleted = '0' and b.blog_id !=1 ";
		if ($blog_id != 0 && $blog_id == (int) $blog_id) {
			$statement .=  " AND b.blog_id != $blog_id ";
		}
		// check for Donncha's site wide tags blog - we don't want to include that
		$potential_tags_blog = get_site_option( 'tags_blog_id');
		if ($potential_tags_blog == (int) $potential_tags_blog && $potential_tags_blog) {
			$statement .= " AND b.blog_id !=  " . $potential_tags_blog . " ";
		}
		$statement = $statement . " ORDER BY b.last_updated desc";
		if ($max_rows > 0) {
			$statement = $statement . " LIMIT $max_rows "; 
		}
		$statement = $statement . ";";
		
		$blog_list = $wpdb->get_results($statement);
		 
   		$blogs_from_topic = array();
		foreach ( $blog_list as $blog ) {
				array_push($blogs_from_topic, $blog);
		}
		
		return $blogs_from_topic;
    	
    }
	
	function get_recent_posts_from_topic_id($topic_id, $max_rows=0, $blog_id) {
		global $wpdb;
		if ($max_rows == 0 OR $max_rows != (int) $max_rows) {
			$max_rows = 10; // limit this to 10 total posts instead of defaulting to as many as there are
		}
		
		$blogs = $this->get_blogs_from_topic_id($topic_id, $max_rows, $blog_id);
		// loop through the blogs and create a big union statement
		$i = 0;
		$sqlstring = "";
		$prefix = substr($wpdb->prefix, 0, stripos($wpdb->prefix, "_")+1);
		foreach($blogs as $blog) {
			if($i>0) $sqlstring .= " UNION ";
			
			$sqlstring .= "SELECT id, post_title, post_date, " . $blog->blog_id . " AS blogid FROM " . $prefix . $blog->blog_id . "_posts WHERE post_type = 'post' and post_status = 'publish' and post_title != 'Hello World!' ";
			$i = 1;
		}
		$sqlstring .=  " order by post_date desc limit " . $max_rows;
		// run the big union statement to get a list of posts to display
		return  $wpdb->get_results($sqlstring);
	
	}
	
	
    
	function get_topic_id_from_blog_id($blog_id) {
		global $wpdb;
		// validate inputs
		if (!$blog_id =  (int) $blog_id) $blog_id = 0;
		$result = $wpdb->get_var($wpdb->prepare("SELECT topic_id FROM $this->table_relationships WHERE blog_id = %d", $blog_id));
		return $result;
	}
        
    function get_blogs_from_topic($topic_name, $max_rows = 0, $blog_id = 0) 
    {
    	global $wpdb, $wpmuBaseTablePrefix;
		// validate inputs
		if (!$max_rows = (int) $max_rows) $max_rows = 0;
		if (!$blog_id =  (int) $blog_id) $blog_id = 0;
		
		// use the prepare statment, because we can't actually validdate $topic_name
    	
    	$topic_id = $wpdb->get_var($wpdb->prepare("SELECT id FROM $this->table_topics
						WHERE topic_name LIKE %s and active = 1", $topic_name));
    	
    	return $this->get_blogs_from_topic_id($topic_id, $maxrows, $blog_id);
    	
    }
    
	function get_recent_posts_from_topic_id_html($topic_id, $max_rows=0, $blog_id=0) {
		global $wpdb;
		$result = $this->get_recent_posts_from_topic_id($topic_id, $max_rows, $blog_id);
			if(sizeof($result > 0)) {
			
			echo("<ul>");
			foreach($result as $post) {
			// get the post
			$link = get_blog_permalink( $post->blogid, $post->id );
			
			echo ("<li><a href='" .$link . "'>" . $post->post_title . "</a></li>");
			

			}
			echo("</ul");
			
			}		
	}
	
	function get_blogs_from_topic_id_html($topic_id, $max_rows = 0, $blog_id = 0)
    {
		$result = $this->get_blogs_from_topic_id($topic_id, $max_rows, $blog_id);
		if(sizeof($result) > 0) {
		echo("<ul>");
    	foreach ($result  as $blog )  {
    		$details = get_blog_details($blog->blog_id);
			echo "<li><a href='http://" . $details->domain . $details->path . "'>" . $details->blogname . "</a></li>";
    	}
		echo("</ul></p>");
		}
    }
    
    function get_blogs_from_topic_html($topic_name, $max_rows = 0)
    {
    	
    	foreach ( $this->get_blogs_from_topic($topic_name, $max_rows) as $blog )  {
    		$details = get_blog_details($blog->blog_id);
			echo "<li><a href='http://" . $details->domain . $details->path . "'>" . $details->blogname  . "</a></li>";
    	}
    }
    
	function get_topic_name($topic_id)
    {
    	global $wpdb;
    	return $wpdb->get_var($wpdb->prepare("SELECT topic_name FROM $this->table_topics
						WHERE id = %s AND active = 1;", $topic_id));
    }
    
	function get_topics()
    {
    	global $wpdb;
    	
    	return $wpdb->get_results("SELECT id, topic_name FROM $this->table_topics WHERE active = 1 ORDER BY topic_name;");
    }
	
	function get_used_topics() 
    {
    	global $wpdb;
    	
		// don't include the main blog
    	return $wpdb->get_results("SELECT distinct id, topic_name FROM $this->table_topics c INNER JOIN $this->table_relationships r ON c.id = r.topic_id WHERE c.active = 1 AND r.blog_id != 1 ORDER BY topic_name;");
				 
    }
    
	function get_topics_html($used = true)
    {	
		if ($used == true) {
			$cats = $this->get_used_topics();
		}
		else {
			$cats = $this->get_topics();
		}
    	foreach ( $cats as $topic )  {
			echo "<li><a href='" .get_settings('siteurl'). "/cets_blog_topics_list.php?idtopic=$topic->id'>" . $topic->topic_name . "</a></li>";
    	}
		
    }
    
	function get_topics_select()
    {
    	global $wpdb;
    	
    	$blog_topic = $this->get_blog_topic($wpdb->blogid);
    	
    	echo "<tr><th valign='top'>Blog Topic:</th><td><select name='blog_topic_id'>";
    	foreach ( $this->get_topics() as $topic )  {
    		if ($blog_topic && $blog_topic == $topic->id) {
    			$selected = "selected='selected'";
    		}
			echo "<option value='$topic->id' ". $selected .">" . $topic->topic_name ."</option>";
			$selected = '';
    	}
    	echo "</select></td></tr>";
    }
	
	function get_topics_table()
    {
    	global $wpdb;
    	
    	$blog_topic = $this->get_blog_topic($wpdb->blogid);
    	
    	echo "<table><tr><th>Topic ID</th><th valign='top'>Blog Topic:</th><th>Edit/Add</th><th>Delete</th></tr>";
    	foreach ( $this->get_topics() as $topic )  {
			
    		echo "<tr><form name='catupdate' method='post'><td align='center'>" . $topic->id . "</td><td><input type='text' name='topic' value='" . $topic->topic_name . "'><input type='hidden' name='topic_id' value='" . $topic->id . "'><td><input type='hidden' name='action' value='edit'><input type='submit' name='edit' value='Edit'>";
			echo "</td></form><td>";
			if ($topic->id != 1) {
				echo "<form name='deletecat' method='post'><input type='hidden' name='action' value='delete'><input type='hidden' name='topicid' value='" . $topic->id . "'><input type='submit' value='Delete'></form>";
			}
			else {
				echo "Topic 1 can not be deleted.";
			}
			
			echo "</td></tr>";
    	}
    	echo "<tr><form name='catadd' method='post'><td>&nbsp;</td><td><input type='text' name='topic' value=''><input type='hidden' name='action' value='add'></td><td><input type='submit' value='Add'></td></tr></table>";
    }
    
	function set_new_blog_topic($blog_id)
    {
    	$topic_id = $_POST['blog_topic_id'];

    	$this->set_blog_topic($blog_id,$topic_id);
    }
    
    
    function set_blog_topic($blog_id, $topic_id = '1') 
    {
    	global $wpdb, $wpmuBaseTablePrefix;
    	$total = $wpdb->get_var($wpdb->prepare("select count(*) from $this->table_relationships WHERE blog_id = %d", $blog_id));
		if ($total == '1') {
			$results = $wpdb->query( $wpdb->prepare("UPDATE $this->table_relationships SET topic_id = %d  WHERE blog_id = %d", $topic_id, $blog_id ) );	
    	} else {
			$results = $wpdb->query( $wpdb->prepare("INSERT INTO  $this->table_relationships (blog_id, topic_id) VALUES (%d, %d)", $blog_id, $topic_id));
		}
    }
    
    function get_blog_topic($blog_id) 
    {
    	global $wpdb;
    	
    	return $wpdb->get_var($wpdb->prepare("select topic_id from  $this->table_relationships  where blog_id = %d", $blog_id));
    }
	
	function get_blog_topic_name($blog_id) 
    {
    	global $wpdb;
    	$result = $wpdb->get_var($wpdb->prepare("select topic_name from $this->table_topics  c INNER JOIN  $this->table_relationships r ON c.id = r.topic_id where r.blog_id =  %d", $blog_id));
		return ($result);
    }
	
	// Added this to make it possible for users to add & update cateories via the admin screens (Deanna 8/26)
	function update_topic($topic_id, $topic){
			global $wpdb;
			$results = $wpdb->query( $wpdb->prepare("UPDATE $this->table_topics SET topic_name =  %s WHERE id =  %d", $topic, $topic_id) );
	}
	
	function add_topic( $topic){
			global $wpdb;
			$results = $wpdb->query( $wpdb->prepare("INSERT INTO $this->table_topics (topic_name) VALUES (%s)", $topic) );
	}
	
	function delete_topic( $topic_id){
			global $wpdb;
			// update all the blogs that have that ID to the #1 required ID.
			$blog_list = $this->get_blogs_from_topic_id($topic_id);
			foreach ( $blog_list as $blog ) {
			$result = $this->set_blog_topic($blog->blog_id, 1);
			}
			
			// delete the topic
			$results = $wpdb->query( $wpdb->prepare("DELETE FROM $this->table_topics WHERE id = %d", $topic_id) );
	}
    
    function add_submenu()
    {
    	add_options_page('Blog Topic Configuration', 'Blog Topic', 10, 'cets_blog_topic', array(&$this,'config_page'));
    }
    
	
    function config_page() 
    {
    	global $wpdb;
    	
    	if ($_POST['action'] == 'update') {
			$this->set_blog_topic($wpdb->blogid,$_POST['blog_topic_id']);
			$updated = true;
    	}
    	if ($updated) { ?>
        <div id="message" class="updated fade"><p><?php _e('Options saved.') ?></p></div>
        <?php	} ?>
        <div class="wrap">
        <h1>Blog Topic</h1>
        <form name="blogtopicform" action="" method="post">
            <table width="100%"  class="editform">
            <?php
                    $this->get_topics_select();
            ?>
            </table>
            <p class="submit">
            <input type="hidden" name="action" value="update" /> 
            <input type="submit" name="Submit" value="<?php _e('Update Options') ?> &raquo;" /> 
            </p>
        </form>
        </div>
        <?php
            }
	
	
	//Add the site-wide administrator menu  (These functions added by Deanna)
	function add_siteadmin_page(){
      if (is_site_admin()) {
        add_submenu_page('wpmu-admin.php', 'Blog Topics Management', 'Blog Topics Management', 10, 'cets_bc_management_page', array(&$this, 'cets_bc_management_page'));
      }
	 }
	 
	 
	 
	 
	 function cets_bc_management_page(){
	 	// Display a list of all the topics to potential edit/add/delete;
	 
	 	global $wpdb;
    	
    	if ($_POST['action'] == 'edit') {
			$this->update_topic($_POST['topic_id'], $_POST['topic']);
			$updated = true;
    	}
		if ($_POST['action'] == 'add') {
			$this->add_topic($_POST['topic']);
			$updated = true;
    	}
		
		if ($_POST['action'] == 'delete') {
			$this->delete_topic($_POST['topicid']);
			$updated = true;
		}
		
    	if ($updated) { ?>
        <div id="message" class="updated fade"><p><?php _e('Options saved.') ?></p></div>
        <?php	} ?>
        <div class="wrap">
        <h1>Update/Add Blog Topics</h1>
          
            <?php
                    $this->get_topics_table();
            ?>
           
           
           
        </div>
        <?php
	 }
	
	
};


$cets_wpmubt = new cets_blog_topics();

// call set up if there's not option set yet
if( get_site_option( 'cets_blogtopics_setup' ) == null ) {
	$cets_wpmubt->setup();
}

	
	
add_action('signup_blogform', array(&$cets_wpmubt, 'get_topics_select'));
add_filter('wpmu_new_blog', array(&$cets_wpmubt, 'set_new_blog_topic'));
add_action('admin_menu', array(&$cets_wpmubt, 'add_submenu'));
add_action('admin_menu', array(&$cets_wpmubt, 'add_siteadmin_page'));


function cets_get_blogs_from_topic_html($topic_name = 'Marketing Extension')
{
    global $cets_wpmubt;
	return $cets_wpmubt->get_blogs_from_topic_html($topic_name);
}

function cets_get_blogs_from_topic_id_html($topic_id = '1', $max_rows = 0, $blog_id = 0)
{
    global $cets_wpmubt;
	return $cets_wpmubt->get_blogs_from_topic_id_html($topic_id, $max_rows, $blog_id);
}

function cets_get_topic_name($topic_id = '1')
{
    global $cets_wpmubt;
	return $cets_wpmubt->get_topic_name($topic_id);
}

function cets_get_topics_html()
{
    global $cets_wpmubt;
	return $cets_wpmubt->get_topics_html();
}

function cets_get_blog_topic_name($blog_id) {
	global $cets_wpmubt;
	return $cets_wpmubt->get_blog_topic_name($blog_id);
}

function cets_get_topic_id_from_blog_id($blog_id) {
	global $cets_wpmubt;
	return $cets_wpmubt->get_topic_id_from_blog_id($blog_id);
}

function cets_get_recent_posts_from_topic_id_html($topic_id, $max_rows=0, $blog_id){
	global $cets_wpmubt;
	return $cets_wpmubt->get_recent_posts_from_topic_id_html($topic_id, $max_rows, $blog_id);
}

	  

?>
